@@ -1,5 +1,9 @@
 from abc import abstractmethod
-from typing import Union, Protocol, List, ContextManager, Any
+from typing import Union, List, ContextManager, Any
+try:
+    from typing import Protocol
+except ImportError:
+    from typing_extensions import Protocol
 
 from .types import InstrumentType
 
@@ -37,5 +41,7 @@ class Instrument(Protocol):
     def use(self) -> ContextManager[Any]:
         """
         Uses the pumpkin_instrument, taking control of it.
+
+        This will automatically close the instrument after exiting the context manager allowing cleanup of outputs/inputs.
         """
-        raise NotImplementedError()
\ No newline at end of file
+        raise NotImplementedError()
