@@ -11,6 +11,7 @@
 # ##############################################################################
 from .types import PowerSupply, PowerSupplyCapability, \
     PowerSupplyChannelCapability, PowerSupplyProtectionMode, PowerSupplyProtectionModeAll
-from .hppsu import HP6621A, HP6622A, HP6623A, HP6624A, HP6627A, HP6632A, HP6633A, HP6634A
+from .hppsu import HP6621A, HP6622A, HP6623A, HP6624A, HP6627A, HP6632A, HP6633A, HP6634A, HP6629A, HP6038A
+from .human import HumanPowerSupply
 from .types import PowerSupplyProtectionModeAll, PowerSupplyProtectionMode, PowerSupplyChannelCapability, \
     PowerSupplyCapability, PowerSupply
