@@ -36,6 +36,7 @@ class HP662XType(Enum):
     HP6623A = 2
     HP6624A = 3
     HP6627A = 4
+    HP6629A = 5
 
 
 HP662XChannelCapabilities = {
@@ -109,6 +110,26 @@ HP662XChannelCapabilities = {
                                                       max_current=2.06,
                                                       max_ocv=55,
                                                       protection_modes=PowerSupplyProtectionModeAll),
+                         PowerSupplyChannelCapability(min_voltage=0,
+                                                      max_voltage=50.5,
+                                                      max_current=2.06,
+                                                      max_ocv=55,
+                                                      protection_modes=PowerSupplyProtectionModeAll)],
+    HP662XType.HP6629A: [PowerSupplyChannelCapability(min_voltage=0,
+                                                      max_voltage=50.5,
+                                                      max_current=2.06,
+                                                      max_ocv=55,
+                                                      protection_modes=PowerSupplyProtectionModeAll),
+                         PowerSupplyChannelCapability(min_voltage=0,
+                                                      max_voltage=50.5,
+                                                      max_current=2.06,
+                                                      max_ocv=55,
+                                                      protection_modes=PowerSupplyProtectionModeAll),
+                         PowerSupplyChannelCapability(min_voltage=0,
+                                                      max_voltage=50.5,
+                                                      max_current=2.06,
+                                                      max_ocv=55,
+                                                      protection_modes=PowerSupplyProtectionModeAll),
                          PowerSupplyChannelCapability(min_voltage=0,
                                                       max_voltage=50.5,
                                                       max_current=2.06,
@@ -120,7 +141,8 @@ HP662XInstrumentCapabilities = {
     HP662XType.HP6622A: PowerSupplyCapability(),
     HP662XType.HP6623A: PowerSupplyCapability(),
     HP662XType.HP6624A: PowerSupplyCapability(),
-    HP662XType.HP6627A: PowerSupplyCapability()
+    HP662XType.HP6627A: PowerSupplyCapability(),
+    HP662XType.HP6629A: PowerSupplyCapability()
 }
 
 
@@ -252,10 +274,11 @@ class _HP662XAContext(PowerSupply):
 
 # ---------------------------- HP663X Types ----------------------------
 class HP663XType(Enum):
-    """Represents the specific HP 663X implementation to use."""
+    """Represents the specific HP 663X or 6038A implementation to use."""
     HP6632A = 0
     HP6633A = 1
     HP6634A = 2
+    HP6038A = 3
 
 
 HP663XChannelCapabilities = {
@@ -273,12 +296,18 @@ HP663XChannelCapabilities = {
                                                       max_voltage=102.4,
                                                       max_current=1.03,
                                                       max_ocv=110,
+                                                      protection_modes=PowerSupplyProtectionModeAll)],
+    HP663XType.HP6038A: [PowerSupplyChannelCapability(min_voltage=0,
+                                                      max_voltage=60,
+                                                      max_current=10,
+                                                      max_ocv=110,
                                                       protection_modes=PowerSupplyProtectionModeAll)]
 }
 HP663XInstrumentCapabilities = {
     HP663XType.HP6632A: PowerSupplyCapability(),
     HP663XType.HP6633A: PowerSupplyCapability(),
-    HP663XType.HP6634A: PowerSupplyCapability()
+    HP663XType.HP6634A: PowerSupplyCapability(),
+    HP663XType.HP6038A: PowerSupplyCapability()
 }
 _HP66XX_TERMINATOR = "\r\n"
 
@@ -337,7 +366,12 @@ class _HP663XAContext(PowerSupply):
         self._write_cmd('VOUT?')
         resp = str(self.controller.read_until(self.address, _HP66XX_TERMINATOR.encode('ascii')), 'ascii')
         resp = resp[:resp.index(_HP66XX_TERMINATOR)]
-        return float(resp)
+        try:
+            resp = float(resp)
+        except ValueError:
+            temp_resp = resp.split()
+            resp = float(temp_resp[1])
+        return resp
 
     def get_output_current(self, channel: int) -> float:
         """Gets the output current on the PSU."""
@@ -346,7 +380,12 @@ class _HP663XAContext(PowerSupply):
         self._write_cmd('IOUT?')
         resp = str(self.controller.read_until(self.address, _HP66XX_TERMINATOR.encode('ascii')), 'ascii')
         resp = resp[:resp.index(_HP66XX_TERMINATOR)]
-        return float(resp)
+        try:
+            resp = float(resp)
+        except ValueError:
+            temp_resp = resp.split()
+            resp = float(temp_resp[1])
+        return resp
 
     def clear_errors(self):
         """Clears the command errors on the power supply via RST command. Same as clear_faults in this case."""
@@ -448,7 +487,7 @@ def HP66XXAInstrument(psu_type):
                 # Prepare the powersupply by zeroing out the settings
                 psu.clear_faults()
                 for i in range(psu.num_channels):
-                    psu.set_output_current(i, 0)
+                    psu.set_output_current(i, 0.1)
                     psu.set_output_voltage(i, 0)
                 yield psu
                 psu.close()
@@ -487,6 +526,11 @@ class HP6627A:
     pass
 
 
+@HP66XXAInstrument(HP662XType.HP6629A)
+class HP6629A:
+    pass
+
+
 @HP66XXAInstrument(HP663XType.HP6632A)
 class HP6632A:
     pass
@@ -500,3 +544,7 @@ class HP6633A:
 @HP66XXAInstrument(HP663XType.HP6634A)
 class HP6634A:
     pass
+
+@HP66XXAInstrument(HP663XType.HP6038A)
+class HP6038A:
+    pass
