@@ -26,4 +26,5 @@ class InstrumentType(Enum):
     """
     PowerSupply = 1,
     Load = 2,
-    Multimeter = 3
+    Multimeter = 3,
+    Switch = 4
